% script that illustrates Kalman filter on a simple model;

% close all 
clear all
close all
clc

%% load and solve the model
m = model('open_model.model','linear',true);
p = setparam;
m = assign(m,p);

m = solve(m);
m = sstate(m); 

%% Create multiple parameterizations if needed
m = alter(m,2);

m.c1_l_y_gap = [0.75 0.75];
m = solve(m);
m = sstate(m); 

ss = get(m,'sstate')

%% Run the IRFs


% run a loop over model shocks
shocks = get(m,'elist');


for iShock = 1:numel(shocks)
  % iterate over shocks
  
  % Create initial condition
  dbinit = zerodb(m,qq(2010,1):qq(2012,4));
  
  % find the name of this shock
  shk = shocks{iShock};
  
  % set the shock to non-zero value in the first period of simulation
  dbinit.(shk)(qq(2013,1)) = 1;
  
  % run the simulation
  s = simulate(m,dbinit,qq(2013,1):qq(2018,1),'deviation', true);
  s = dboverlay(s, dbinit);
  
  % make a picture showing the IRFs
  figure('Name',['IRF to ' shk]);
  subplot(331);
    plot(s.l_y_gap,'lineWidth',3);
    grid;
    title('Output gap (%)');
    legend('Model 1', 'Model 2');
  subplot(332);
    plot(s.dl_cpi,'lineWidth',3);
    grid;
    title('Inflation (%)');
  subplot(333);
    plot(s.i,'lineWidth',3);
    grid;
    title('Nominal interest rate (%)');    
  subplot(334);
    plot(s.r_gap,'lineWidth',3);
    grid;
    title('Real interest rate gap (pp)');   
  subplot(335);
    plot(s.l_z_gap,'lineWidth',3);
    grid;
    title('Real exchange rate gap (pp)'); 
  subplot(336);
    plot(s.l_cpi,'lineWidth',3);
    grid;
    title('Price level (100*log)'); 
  subplot(337);
    plot(s.l_s,'lineWidth',3);
    grid;
    title('Nominal exchange rate (100*log)');
  subplot(338);
    plot(s.l_z,'lineWidth',3);
    grid;
    title('Real exchange rate (100*log)');    
end



